@@ -77,13 +77,13 @@ OverviewMapHolder :: OverviewMapHolder( GameMap& gamemap ) : map(gamemap), initi
 void OverviewMapHolder :: connect()
 {
    if ( !connected ) {
-      idleEvent.connect ( SigC::slot( *this, &OverviewMapHolder::idleHandler ));
+      idleEvent.connect ( sigc::mem_fun( *this, &OverviewMapHolder::idleHandler ));
       connected = true;
    }
 }
 
 
-SigC::Signal0<void> OverviewMapHolder::generationComplete;
+sigc::signal<void> OverviewMapHolder::generationComplete;
 
 bool OverviewMapHolder :: idleHandler( )
 {
@@ -1467,9 +1467,9 @@ void GameMap::objectGrowth()
    checkunitsforremoval( this );
 }
 
-SigC::Signal1<void,GameMap&> GameMap::sigMapDeletion;
-SigC::Signal1<void,GameMap&> GameMap::sigMapCreation;
-SigC::Signal2<void,GameMap*,Player&> GameMap::sigPlayerTurnEndsStatic;
+sigc::signal<void,GameMap&> GameMap::sigMapDeletion;
+sigc::signal<void,GameMap&> GameMap::sigMapCreation;
+sigc::signal<void,GameMap*,Player&> GameMap::sigPlayerTurnEndsStatic;
 
 GameMap :: ~GameMap ()
 {
@@ -2276,7 +2276,7 @@ GameParameterSettings gameParameterSettings[gameparameternum ] = {
       {  "TrainingIncrement",                  2,                    1,   maxunitexperience,  true,   false,   "training centers: training increment"},   //       cgp_trainingIncrement,              
       {  "ExperienceEffectDivisorAttack",      1,                    1,   10,                 false,  false,   "experience effect divisor for attack"},  //       gp_experienceDivisorAttack
       {  "DisableDirectView",                  1,                    0,   1,                  false,  false,   "disable direct View"},  //       cgp_disableDirectView
-      {  "DisableUnitTrade",                   0,                    0,   1,                  false,  false,   "disable transfering units/buildings to other players"},  //       cgp_disableUnitTransfer
+      {  "DisableUnitTrade",                   0,                    0,   1,                  false,  false,   "disable transferring units/buildings to other players"},  //       cgp_disableUnitTransfer
       {  "ExperienceEffectDivisorDefense",     1,                    1,   10,                 false,  false,   "experience effect divisor for defense"},  //       cgp_experienceDivisorDefense
       {  "DebugGameEvents",                    0,                    0,   2,                  true,   false,   "debug game events"},  //       cgp_debugEvents
       {  "ObjectGrowthRate",                   0,                    0,   maxint,             true,   false,   "Object growth rate (percentage)" },  //       cgp_objectGrowthMultiplier
